# fake_bpy
A module that you can use to run your bpy scripts without import errors.

<br>

### How to install
Run this command in your terminal: ```pip install fake-bpy```

### How to use
```py
import fake_bpy as bpy

# Rest of your bpy program
```
